==> v4_navigation_engine-0.1.47.tar.gz: ios/Classes/NavigationV4/Models/RouteInformation.swift <==
//
//  RouteInformation.swift
//  NavigationUI
//
//  Created by Hassine on 17/06/2020.
//  Copyright © 2020 com.mile. All rights reserved.
//

import Foundation
import CoreLocation


public class RouteInformation  {


    public var key: String
    
    //public var ref: DatabaseReference?
    
    public var imageURL: String?
    
    public var coordinatesGPX: [CLLocationCoordinate2D] = [CLLocationCoordinate2D]()
    
    public var coordinatesPolyline: [CLLocationCoordinate2D] = [CLLocationCoordinate2D]()
    
    public var isNavigationActivated: Bool
    
    public var cityId: String

    var idDestination: String

    public var city: City?
    
    public var shareUrl: String?
    
    public var poisId: [String] = []

    public var sponsorsId: [String] = []
    
    public var pois :[PointOfInterest] = []

    public var sportSession :[SportSession] = []

    public var sponsors :[Sponsor] = []
    
    public var directionals :[PointOfInterest] = []
    
    public var averageDuration: Int?
    
    public var length: Int?

    public var distance: Int?
    
    public var ascent: Int?
    
    public var isStartingPointStatic = false

    public var isLoop : Bool = false
    
    //public var profileIdentifier: Int = 0
    public var profileIdentifier: String = "walking"

    public var isHoraire: Bool

    public var typeRoute : TypeRoute = .none
    
    private var nameFr: String?
    private var nameEn: String?
    private var nameEs: String?
    private var nameDe: String?
    private var nameIt: String?
    private var nameNl: String?
    private var namePt: String?
    
    private var descriptionFr : String?
    private var descriptionEn : String?
    private var descriptionIt : String?
    private var descriptionEs : String?
    private var descriptionNl : String?
    private var descriptionPt : String?
    private var descriptionDe : String?

    
    public var description: String? {
        get {
            return MyUtils.translateToSelectedLanguage(en: descriptionEn, fr: descriptionFr, es: descriptionEs, it: descriptionIt, de: descriptionDe, nl: descriptionNl, pt: descriptionPt)
        }
    }
    
    public  var name: String? {
        get {
            return MyUtils.translateToSelectedLanguage(en: nameEn, fr: nameFr, es: nameEs, it: nameIt, de: nameDe, nl: nameNl, pt: namePt)
        }
    }

    init(snapshotValue: [String: Any], directionCriteria: String) {
        profileIdentifier = directionCriteria
        let arrayDescription = snapshotValue["arrayDescription"] as? [String: String]
        descriptionEn = arrayDescription!["EN"] ?? ""
        descriptionFr = arrayDescription!["FR"] ?? ""
        let arrayName = snapshotValue["arrayName"] as? [String: String]
        nameEn = arrayName!["EN"] ?? ""
        nameFr = arrayName!["FR"] ?? ""
        imageURL = snapshotValue["imageURL"] as? String ?? ""
        averageDuration = snapshotValue["averageDuration"] as? Int ?? 0
        length = snapshotValue["length"] as? Int ?? 0
        ascent = snapshotValue["ascent"] as? Int ?? 0
        isNavigationActivated = snapshotValue["isNavigationActivated"] as? Bool ?? true
        isHoraire = snapshotValue["isHoraire"] as? Bool ?? true
        isLoop = snapshotValue["isLoop"] as? Bool ?? true
        if let pois = snapshotValue["pois"] as? [String] {
            for poi in pois {
                poisId.append(poi)
            }
        }
        cityId = ""
        if let cities = snapshotValue["IdCity"] as? NSArray {
            cityId = cities.firstObject as! String
        }

        isStartingPointStatic = snapshotValue["isStartingPointStatic"] as? Bool ?? false

        idDestination = snapshotValue["idDestination"] as? String ?? ""
        let typeRoutes = snapshotValue["methodLocomotion"]
        let index = typeRoutes as? Int ?? -1
        typeRoute = TypeRoute(rawValue : index) ?? .none


        if let coordinates = snapshotValue["arrayCoordinates"] as? [[String: Double]] {
            for coordinate in coordinates{
                let latitude = coordinate["latitude"] ?? 0
                let longitude = coordinate["longitude"] ?? 0
                let gpx = CLLocationCoordinate2D.init(latitude: latitude, longitude: longitude)
                coordinatesGPX.append(gpx)
            }
        }

        //ref = ""
        self.key = snapshotValue["id"] as? String ?? ""
    }

    /*init(snapshotValue: [String:Any]) {

        self.key = snapshotValue["id"] as? String ?? "" // key

        if let dictName = snapshotValue["Name"] as? NSDictionary
        {
            nameEn = dictName["EN"] as? String ?? nil
            nameFr = dictName["FR"] as? String ?? nil
            nameIt = dictName["IT"] as? String ?? nil
            nameEs = dictName["ES"] as? String ?? nil
            nameDe = dictName["DE"] as? String ?? nil
            nameNl = dictName["NL"] as? String ?? nil
            namePt = dictName["PT"] as? String ?? nil
        }

        if let dictDescription = snapshotValue["Description"] as? NSDictionary
        {
            descriptionEn = dictDescription["EN"] as? String ?? nil
            descriptionFr = dictDescription["FR"] as? String ?? nil
            descriptionDe = dictDescription["DE"] as? String ?? nil
            descriptionPt = dictDescription["PT"] as? String ?? nil
            descriptionEs = dictDescription["ES"] as? String ?? nil
            descriptionIt = dictDescription["IT"] as? String ?? nil
            descriptionNl = dictDescription["NL"] as? String ?? nil
        }


        if let sponsors = snapshotValue["Sponsors"] as? NSArray
                   {
                       for sponsor in sponsors
                       {
                           sponsorsId.append(sponsor as! String)
                       }
                   }

        imageURL = snapshotValue["imageURL"] as? String
        isStartingPointStatic = snapshotValue["isStartingPointStatic"] as? Bool ?? false
        averageDuration = snapshotValue["averageDuration"] as? Int ?? nil
        length = snapshotValue["Length"] as? Int ?? 0
        ascent = snapshotValue["Ascent"] as? Int ?? 0
        isNavigationActivated = snapshotValue["isNavigationActivated"] as? Bool ?? true
        if let shareUrlDictionnary = snapshotValue["ShareUrl"] as? NSMutableDictionary
        {
            shareUrl =   shareUrlDictionnary["EN"] as? String
        }

        if let pois = snapshotValue["POI"] as? NSArray
        {
            for poi in pois
            {
                poisId.append(poi as! String)
            }
        }
        cityId = ""
        if let cities = snapshotValue["IdCity"] as? NSArray
               {
                cityId = cities.firstObject as! String


               }
        if let typeRoutes = snapshotValue["typeTransportation"] as? NSArray
        {
            let index = typeRoutes[0] as? Int ?? -1
            // typeRoute = TypeRoute(rawValue : index) ?? .none
        }


        if let coordinates = (snapshotValue["MapperCoordinates"] as? NSMutableDictionary)?.value(forKey: "feet\(key)") as? NSDictionary
        {
            profileIdentifier = 0

            let sortedCoordinates = coordinates.sorted { (a, b) -> Bool in
                let key1 = Int(a.key as! String)
                let key2 = Int(b.key as! String)
                return key1! < key2!

            }


            for coordinate in sortedCoordinates
            {
                if let dict = coordinate.value as? NSMutableArray
                {
                    let latitude =  dict[1] as? Double ?? 0
                    let longitude = dict[0] as? Double ?? 0
                    let gpx = CLLocationCoordinate2D.init(latitude: latitude, longitude: longitude)
                    coordinatesGPX.append(gpx)
                }
            }
        } else  if let coordinates = (snapshotValue["MapperCoordinates"] as? NSMutableDictionary)?.value(forKey: "bike\(key)") as? NSDictionary
        {
            profileIdentifier = 1
            let sortedCoordinates = coordinates.sorted { (a, b) -> Bool in
                let key1 = Int(a.key as! String)
                let key2 = Int(b.key as! String)
                return key1! < key2!
            }


            for coordinate in sortedCoordinates
            {
                if let dict = coordinate.value as? NSMutableArray
                {
                    let latitude =  dict[1] as? Double ?? 0
                    let longitude = dict[0] as? Double ?? 0
                    let gpx = CLLocationCoordinate2D.init(latitude: latitude, longitude: longitude)
                    coordinatesGPX.append(gpx)
                }
            }
        }

        if let coordinates = (snapshotValue["MapperCoordinates"] as? NSMutableDictionary)?.value(forKey: "preview\(key)") as? NSDictionary
        {
            let sortedCoordinates = coordinates.sorted { (a, b) -> Bool in
                let key1 = Int(a.key as! String)
                let key2 = Int(b.key as! String)
                return key1! < key2!

            }


            for coordinate in sortedCoordinates
            {
                if let dict = coordinate.value as? NSMutableArray
                {
                    let latitude =  dict[1] as? Double ?? 0
                    let longitude = dict[0] as? Double ?? 0
                    let gpx = CLLocationCoordinate2D.init(latitude: latitude, longitude: longitude)
                    coordinatesPolyline.append(gpx)
                }
            }
        }

    }*/
}




public enum Category : Int {
        case tourism = 0
        case challenge = 1
        case sport = 2
        case theme = 3
        
        public var description: String {
            switch (self) {
            case .tourism: return "TOURISM_CATEGORY".localized
            case .sport:return "SPORT_CATEGORY".localized
            case .challenge:return "CHALLENGE_CATEGORY".localized
            case .theme:return "THEME_CATEGORY".localized

                
            }
        }


    public var color : UIColor
    {
        switch (self) {
                    case .tourism:
            return UIColor(red: 0.97, green: 0.73, blue: 0.23, alpha: 1.00)
        case .challenge:
            return UIColor(red: 0.97, green: 0.23, blue: 0.41, alpha: 1.00)
        case .sport:
            return UIColor(red: 0.20, green: 0.72, blue: 0.88, alpha: 1.00)
        case .theme:
            return UIColor(red: 0.77, green: 0.25, blue: 0.85, alpha: 1.00)
        }
    }

}


public class RouteInformationService  {
    
    //var db : Firestore!
    public init() {
        /*db = Firestore.firestore()
        //      FirebaseApp.configure()
        //   Database.database().isPersistenceEnabled = true

        let settings = FirestoreSettings()
        settings.isPersistenceEnabled = true
        Firestore.firestore().settings = settings*/
        
    }
}



public enum Result<T> {
    case success(T)
    case failure(Error)
}

==> v4_navigation_engine-0.1.55.tar.gz: ios/Classes/NavigationV4/Models/RouteInformation.swift <==
//
//  RouteInformation.swift
//  NavigationUI
//
//  Created by Hassine on 17/06/2020.
//  Copyright © 2020 com.mile. All rights reserved.
//

import Foundation
import CoreLocation


public class RouteInformation  {


    public var key: String
    
    //public var ref: DatabaseReference?
    
    public var imageURL: String?
    
    public var coordinatesGPX: [CLLocationCoordinate2D] = [CLLocationCoordinate2D]()
    
    public var coordinatesPolyline: [CLLocationCoordinate2D] = [CLLocationCoordinate2D]()
    
    public var isNavigationActivated: Bool
    
    public var cityId: String

    var idDestination: String

    public var city: City?
    
    public var shareUrl: String?
    
    public var poisId: [String] = []

    public var sponsorsId: [String] = []
    
    public var pois :[PointOfInterest] = []

    public var sportSession :[SportSession] = []

    public var sponsors :[Sponsor] = []
    
    public var directionals :[PointOfInterest] = []
    
    public var averageDuration: Int?
    
    public var length: Int?

    public var distance: Int?
    
    public var ascent: Int?
    
    public var isStartingPointStatic = false

    public var isLoop : Bool = false
    
    //public var profileIdentifier: Int = 0
    public var profileIdentifier: String = "walking"

    public var isHoraire: Bool

    public var typeRoute : TypeRoute = .none
    
    private var nameFr: String?
    private var nameEn: String?
    private var nameEs: String?
    private var nameDe: String?
    private var nameIt: String?
    private var nameNl: String?
    private var namePt: String?
    
    private var descriptionFr : String?
    private var descriptionEn : String?
    private var descriptionIt : String?
    private var descriptionEs : String?
    private var descriptionNl : String?
    private var descriptionPt : String?
    private var descriptionDe : String?

    
    public var description: String? {
        get {
            return MyUtils.translateToSelectedLanguage(en: descriptionEn, fr: descriptionFr, es: descriptionEs, it: descriptionIt, de: descriptionDe, nl: descriptionNl, pt: descriptionPt)
        }
    }
    
    public  var name: String? {
        get {
            return MyUtils.translateToSelectedLanguage(en: nameEn, fr: nameFr, es: nameEs, it: nameIt, de: nameDe, nl: nameNl, pt: namePt)
        }
    }

    init(snapshotValue: [String: Any], directionCriteria: String) {
        profileIdentifier = directionCriteria
        /*let arrayDescription = snapshotValue["arrayDescription"] as? [String: String]
        descriptionEn = arrayDescription!["EN"] ?? ""
        descriptionFr = arrayDescription!["FR"] ?? ""
        let arrayName = snapshotValue["arrayName"] as? [String: String]
        nameEn = arrayName!["EN"] ?? ""
        nameFr = arrayName!["FR"] ?? ""*/
        imageURL = snapshotValue["imageURL"] as? String ?? ""
        averageDuration = snapshotValue["averageDuration"] as? Int ?? 0
        length = snapshotValue["length"] as? Int ?? 0
        ascent = snapshotValue["ascent"] as? Int ?? 0
        isNavigationActivated = snapshotValue["isNavigationActivated"] as? Bool ?? true
        isHoraire = snapshotValue["isHoraire"] as? Bool ?? true
        isLoop = snapshotValue["isLoop"] as? Bool ?? true
        if let pois = snapshotValue["pois"] as? [String] {
            for poi in pois {
                poisId.append(poi)
            }
        }
        cityId = ""
        if let cities = snapshotValue["IdCity"] as? NSArray {
            cityId = cities.firstObject as! String
        }

        isStartingPointStatic = snapshotValue["isStartingPointStatic"] as? Bool ?? false

        idDestination = snapshotValue["idDestination"] as? String ?? ""
        let typeRoutes = snapshotValue["methodLocomotion"]
        let index = typeRoutes as? Int ?? -1
        typeRoute = TypeRoute(rawValue : index) ?? .none


        if let coordinates = snapshotValue["arrayCoordinates"] as? [[String: Double]] {
            for coordinate in coordinates{
                let latitude = coordinate["latitude"] ?? 0
                let longitude = coordinate["longitude"] ?? 0
                let gpx = CLLocationCoordinate2D.init(latitude: latitude, longitude: longitude)
                coordinatesGPX.append(gpx)
            }
        }

        //ref = ""
        self.key = snapshotValue["id"] as? String ?? ""
    }

    /*init(snapshotValue: [String:Any]) {

        self.key = snapshotValue["id"] as? String ?? "" // key

        if let dictName = snapshotValue["Name"] as? NSDictionary
        {
            nameEn = dictName["EN"] as? String ?? nil
            nameFr = dictName["FR"] as? String ?? nil
            nameIt = dictName["IT"] as? String ?? nil
            nameEs = dictName["ES"] as? String ?? nil
            nameDe = dictName["DE"] as? String ?? nil
            nameNl = dictName["NL"] as? String ?? nil
            namePt = dictName["PT"] as? String ?? nil
        }

        if let dictDescription = snapshotValue["Description"] as? NSDictionary
        {
            descriptionEn = dictDescription["EN"] as? String ?? nil
            descriptionFr = dictDescription["FR"] as? String ?? nil
            descriptionDe = dictDescription["DE"] as? String ?? nil
            descriptionPt = dictDescription["PT"] as? String ?? nil
            descriptionEs = dictDescription["ES"] as? String ?? nil
            descriptionIt = dictDescription["IT"] as? String ?? nil
            descriptionNl = dictDescription["NL"] as? String ?? nil
        }


        if let sponsors = snapshotValue["Sponsors"] as? NSArray
                   {
                       for sponsor in sponsors
                       {
                           sponsorsId.append(sponsor as! String)
                       }
                   }

        imageURL = snapshotValue["imageURL"] as? String
        isStartingPointStatic = snapshotValue["isStartingPointStatic"] as? Bool ?? false
        averageDuration = snapshotValue["averageDuration"] as? Int ?? nil
        length = snapshotValue["Length"] as? Int ?? 0
        ascent = snapshotValue["Ascent"] as? Int ?? 0
        isNavigationActivated = snapshotValue["isNavigationActivated"] as? Bool ?? true
        if let shareUrlDictionnary = snapshotValue["ShareUrl"] as? NSMutableDictionary
        {
            shareUrl =   shareUrlDictionnary["EN"] as? String
        }

        if let pois = snapshotValue["POI"] as? NSArray
        {
            for poi in pois
            {
                poisId.append(poi as! String)
            }
        }
        cityId = ""
        if let cities = snapshotValue["IdCity"] as? NSArray
               {
                cityId = cities.firstObject as! String


               }
        if let typeRoutes = snapshotValue["typeTransportation"] as? NSArray
        {
            let index = typeRoutes[0] as? Int ?? -1
            // typeRoute = TypeRoute(rawValue : index) ?? .none
        }


        if let coordinates = (snapshotValue["MapperCoordinates"] as? NSMutableDictionary)?.value(forKey: "feet\(key)") as? NSDictionary
        {
            profileIdentifier = 0

            let sortedCoordinates = coordinates.sorted { (a, b) -> Bool in
                let key1 = Int(a.key as! String)
                let key2 = Int(b.key as! String)
                return key1! < key2!

            }


            for coordinate in sortedCoordinates
            {
                if let dict = coordinate.value as? NSMutableArray
                {
                    let latitude =  dict[1] as? Double ?? 0
                    let longitude = dict[0] as? Double ?? 0
                    let gpx = CLLocationCoordinate2D.init(latitude: latitude, longitude: longitude)
                    coordinatesGPX.append(gpx)
                }
            }
        } else  if let coordinates = (snapshotValue["MapperCoordinates"] as? NSMutableDictionary)?.value(forKey: "bike\(key)") as? NSDictionary
        {
            profileIdentifier = 1
            let sortedCoordinates = coordinates.sorted { (a, b) -> Bool in
                let key1 = Int(a.key as! String)
                let key2 = Int(b.key as! String)
                return key1! < key2!
            }


            for coordinate in sortedCoordinates
            {
                if let dict = coordinate.value as? NSMutableArray
                {
                    let latitude =  dict[1] as? Double ?? 0
                    let longitude = dict[0] as? Double ?? 0
                    let gpx = CLLocationCoordinate2D.init(latitude: latitude, longitude: longitude)
                    coordinatesGPX.append(gpx)
                }
            }
        }

        if let coordinates = (snapshotValue["MapperCoordinates"] as? NSMutableDictionary)?.value(forKey: "preview\(key)") as? NSDictionary
        {
            let sortedCoordinates = coordinates.sorted { (a, b) -> Bool in
                let key1 = Int(a.key as! String)
                let key2 = Int(b.key as! String)
                return key1! < key2!

            }


            for coordinate in sortedCoordinates
            {
                if let dict = coordinate.value as? NSMutableArray
                {
                    let latitude =  dict[1] as? Double ?? 0
                    let longitude = dict[0] as? Double ?? 0
                    let gpx = CLLocationCoordinate2D.init(latitude: latitude, longitude: longitude)
                    coordinatesPolyline.append(gpx)
                }
            }
        }

    }*/
}




public enum Category : Int {
        case tourism = 0
        case challenge = 1
        case sport = 2
        case theme = 3
        
        public var description: String {
            switch (self) {
            case .tourism: return "TOURISM_CATEGORY".localized
            case .sport:return "SPORT_CATEGORY".localized
            case .challenge:return "CHALLENGE_CATEGORY".localized
            case .theme:return "THEME_CATEGORY".localized

                
            }
        }


    public var color : UIColor
    {
        switch (self) {
                    case .tourism:
            return UIColor(red: 0.97, green: 0.73, blue: 0.23, alpha: 1.00)
        case .challenge:
            return UIColor(red: 0.97, green: 0.23, blue: 0.41, alpha: 1.00)
        case .sport:
            return UIColor(red: 0.20, green: 0.72, blue: 0.88, alpha: 1.00)
        case .theme:
            return UIColor(red: 0.77, green: 0.25, blue: 0.85, alpha: 1.00)
        }
    }

}


public class RouteInformationService  {
    
    //var db : Firestore!
    public init() {
        /*db = Firestore.firestore()
        //      FirebaseApp.configure()
        //   Database.database().isPersistenceEnabled = true

        let settings = FirestoreSettings()
        settings.isPersistenceEnabled = true
        Firestore.firestore().settings = settings*/
        
    }
}



public enum Result<T> {
    case success(T)
    case failure(Error)
}
